Enum nuts_container::container::Error
source · pub enum Error<B: Backend> {
Backend(B::Err),
Bytes(Error),
OpenSSL(ErrorStack),
InvalidKey,
InvalidIv,
InvalidBlockSize,
NotTrustworthy,
NoPassword,
PasswordCallback(String),
WrongPassword(Error),
NullId,
}Expand description
Error type used by this module.
Variants
Backend(B::Err)
An error occured in the attached backend.
Bytes(Error)
Error while (de-) serializing binary data.
OpenSSL(ErrorStack)
An error in the OpenSSL library occured.
InvalidKey
The cipher key is invalid/too short.
InvalidIv
The cipher iv is invalid/too short.
InvalidBlockSize
The size of the block to be encrypted/decrypted is invalid and must be aligned at the block size of the cipher.
NotTrustworthy
A cipher-text is not trustworthy.
If an authenticated decryption is performed, and the tag mismatches, this error is raised.
NoPassword
No password callback is assigned to the container, thus no password is available.
PasswordCallback(String)
The password callback generated an error, which is passed to the variant.
WrongPassword(Error)
The password is wrong.
NullId
Try to read/write from/to a null-id which is forbidden.